@@ -4,8 +4,17 @@ import re
 from typing import Any, Union
 
 from .api import ImouAPIClient
-from .const import BINARY_SENSORS, BUTTONS, IMOU_CAPABILITIES, IMOU_SWITCHES, SELECT, SENSORS, SIRENS
-from .device_entity import ImouBinarySensor, ImouButton, ImouEntity, ImouSelect, ImouSensor, ImouSiren, ImouSwitch
+from .const import BINARY_SENSORS, BUTTONS, CAMERAS, IMOU_CAPABILITIES, IMOU_SWITCHES, SELECT, SENSORS, SIRENS
+from .device_entity import (
+    ImouBinarySensor,
+    ImouButton,
+    ImouCamera,
+    ImouEntity,
+    ImouSelect,
+    ImouSensor,
+    ImouSiren,
+    ImouSwitch,
+)
 from .exceptions import InvalidResponse
 
 _LOGGER: logging.Logger = logging.getLogger(__package__)
@@ -45,6 +54,7 @@ class ImouDevice:
             "select": [],
             "button": [],
             "siren": [],
+            "camera": [],
         }
 
         self._initialized = False
@@ -246,6 +256,15 @@ class ImouDevice:
                         "siren",
                     )
                 )
+            # add camera
+            self._sensor_instances["camera"].append(
+                ImouCamera(
+                    self._api_client,
+                    self._device_id,
+                    self.get_name(),
+                    "camera",
+                )
+            )
         except Exception as exception:
             raise InvalidResponse(f" missing parameter or error parsing in {device_data}") from exception
         _LOGGER.debug("Retrieved device %s", self.to_string())
@@ -377,6 +396,18 @@ class ImouDevice:
             sensor["is_updated"] = sensor_instance.is_updated()
             sensor["attributes"] = sensor_instance.get_attributes()
             sirens.append(sensor)
+        # prepare cameras
+        cameras = []
+        for sensor_instance in self._sensor_instances["camera"]:
+            sensor = {}
+            sensor_name = sensor_instance.get_name()
+            description = f"{CAMERAS[sensor_name]} ({sensor_name})" if sensor_name in CAMERAS else sensor_name
+            sensor["name"] = sensor_name
+            sensor["description"] = description
+            sensor["is_enabled"] = sensor_instance.is_enabled()
+            sensor["is_updated"] = sensor_instance.is_updated()
+            sensor["attributes"] = sensor_instance.get_attributes()
+            cameras.append(sensor)
         # prepare data structure to return
         data: dict[str, Any] = {
             "api": {
@@ -401,6 +432,7 @@ class ImouDevice:
             "selects": selects,
             "buttons": buttons,
             "sirens": sirens,
+            "cameras": cameras,
         }
         return data
 
@@ -439,6 +471,9 @@ class ImouDevice:
         dump = dump + "    Sirens: \n"
         for siren in data['sirens']:
             dump = dump + f"        - {siren['description']}: {siren['state']} {siren['attributes']}\n"
+        dump = dump + "    Cameras: \n"
+        for camera in data['cameras']:
+            dump = dump + f"        - {camera['description']}: {camera['attributes']}\n"
         return dump
 
 
